diff mbox

[U-Boot,v2,01/19] dm: i2c: Add a dm_ prefix to driver model bus speed functions

Message ID 1423197710-1568-2-git-send-email-sjg@chromium.org
State Accepted
Delegated to: Simon Glass
Headers show

Commit Message

Simon Glass Feb. 6, 2015, 4:41 a.m. UTC
As with i2c_read() and i2c_write(), add a dm_ prefix to the driver model
versions of these functions to avoid conflicts.

Signed-off-by: Simon Glass <sjg@chromium.org>
---

Changes in v2:
- Use a dm_ prefix for remaining conflicting I2C functions

 common/cmd_i2c.c         |  4 ++--
 drivers/i2c/i2c-uclass.c | 11 +++--------
 include/i2c.h            |  8 ++++----
 test/dm/i2c.c            |  6 +++---
 4 files changed, 12 insertions(+), 17 deletions(-)

Comments

Heiko Schocher Feb. 6, 2015, 7:12 a.m. UTC | #1
Hello Simon,

Am 06.02.2015 05:41, schrieb Simon Glass:
> As with i2c_read() and i2c_write(), add a dm_ prefix to the driver model
> versions of these functions to avoid conflicts.
>
> Signed-off-by: Simon Glass <sjg@chromium.org>
> ---
>
> Changes in v2:
> - Use a dm_ prefix for remaining conflicting I2C functions
>
>   common/cmd_i2c.c         |  4 ++--
>   drivers/i2c/i2c-uclass.c | 11 +++--------
>   include/i2c.h            |  8 ++++----
>   test/dm/i2c.c            |  6 +++---
>   4 files changed, 12 insertions(+), 17 deletions(-)

Thanks!

Acked-by: Heiko Schocher <hs@denx.de>

bye,
Heiko
>
> diff --git a/common/cmd_i2c.c b/common/cmd_i2c.c
> index 7c3ad00..fe8f77a 100644
> --- a/common/cmd_i2c.c
> +++ b/common/cmd_i2c.c
> @@ -1730,7 +1730,7 @@ static int do_i2c_bus_speed(cmd_tbl_t * cmdtp, int flag, int argc, char * const
>   #endif
>   	if (argc == 1) {
>   #ifdef CONFIG_DM_I2C
> -		speed = i2c_get_bus_speed(bus);
> +		speed = dm_i2c_get_bus_speed(bus);
>   #else
>   		speed = i2c_get_bus_speed();
>   #endif
> @@ -1740,7 +1740,7 @@ static int do_i2c_bus_speed(cmd_tbl_t * cmdtp, int flag, int argc, char * const
>   		speed = simple_strtoul(argv[1], NULL, 10);
>   		printf("Setting bus speed to %d Hz\n", speed);
>   #ifdef CONFIG_DM_I2C
> -		ret = i2c_set_bus_speed(bus, speed);
> +		ret = dm_i2c_set_bus_speed(bus, speed);
>   #else
>   		ret = i2c_set_bus_speed(speed);
>   #endif
> diff --git a/drivers/i2c/i2c-uclass.c b/drivers/i2c/i2c-uclass.c
> index eafa457..a6991bf 100644
> --- a/drivers/i2c/i2c-uclass.c
> +++ b/drivers/i2c/i2c-uclass.c
> @@ -325,7 +325,7 @@ int dm_i2c_probe(struct udevice *bus, uint chip_addr, uint chip_flags,
>   	return ret;
>   }
>
> -int i2c_set_bus_speed(struct udevice *bus, unsigned int speed)
> +int dm_i2c_set_bus_speed(struct udevice *bus, unsigned int speed)
>   {
>   	struct dm_i2c_ops *ops = i2c_get_ops(bus);
>   	struct dm_i2c_bus *i2c = bus->uclass_priv;
> @@ -346,12 +346,7 @@ int i2c_set_bus_speed(struct udevice *bus, unsigned int speed)
>   	return 0;
>   }
>
> -/*
> - * i2c_get_bus_speed:
> - *
> - *  Returns speed of selected I2C bus in Hz
> - */
> -int i2c_get_bus_speed(struct udevice *bus)
> +int dm_i2c_get_bus_speed(struct udevice *bus)
>   {
>   	struct dm_i2c_ops *ops = i2c_get_ops(bus);
>   	struct dm_i2c_bus *i2c = bus->uclass_priv;
> @@ -440,7 +435,7 @@ static int i2c_post_probe(struct udevice *dev)
>   	i2c->speed_hz = fdtdec_get_int(gd->fdt_blob, dev->of_offset,
>   				     "clock-frequency", 100000);
>
> -	return i2c_set_bus_speed(dev, i2c->speed_hz);
> +	return dm_i2c_set_bus_speed(dev, i2c->speed_hz);
>   }
>
>   static int i2c_post_bind(struct udevice *dev)
> diff --git a/include/i2c.h b/include/i2c.h
> index 27fe00f..1635e9a 100644
> --- a/include/i2c.h
> +++ b/include/i2c.h
> @@ -125,21 +125,21 @@ int dm_i2c_probe(struct udevice *bus, uint chip_addr, uint chip_flags,
>   		 struct udevice **devp);
>
>   /**
> - * i2c_set_bus_speed() - set the speed of a bus
> + * dm_i2c_set_bus_speed() - set the speed of a bus
>    *
>    * @bus:	Bus to adjust
>    * @speed:	Requested speed in Hz
>    * @return 0 if OK, -EINVAL for invalid values
>    */
> -int i2c_set_bus_speed(struct udevice *bus, unsigned int speed);
> +int dm_i2c_set_bus_speed(struct udevice *bus, unsigned int speed);
>
>   /**
> - * i2c_get_bus_speed() - get the speed of a bus
> + * dm_i2c_get_bus_speed() - get the speed of a bus
>    *
>    * @bus:	Bus to check
>    * @return speed of selected I2C bus in Hz, -ve on error
>    */
> -int i2c_get_bus_speed(struct udevice *bus);
> +int dm_i2c_get_bus_speed(struct udevice *bus);
>
>   /**
>    * i2c_set_chip_flags() - set flags for a chip
> diff --git a/test/dm/i2c.c b/test/dm/i2c.c
> index ef88372..541b73b 100644
> --- a/test/dm/i2c.c
> +++ b/test/dm/i2c.c
> @@ -67,10 +67,10 @@ static int dm_test_i2c_speed(struct dm_test_state *dms)
>
>   	ut_assertok(uclass_get_device_by_seq(UCLASS_I2C, busnum, &bus));
>   	ut_assertok(i2c_get_chip(bus, chip, 1, &dev));
> -	ut_assertok(i2c_set_bus_speed(bus, 100000));
> +	ut_assertok(dm_i2c_set_bus_speed(bus, 100000));
>   	ut_assertok(dm_i2c_read(dev, 0, buf, 5));
> -	ut_assertok(i2c_set_bus_speed(bus, 400000));
> -	ut_asserteq(400000, i2c_get_bus_speed(bus));
> +	ut_assertok(dm_i2c_set_bus_speed(bus, 400000));
> +	ut_asserteq(400000, dm_i2c_get_bus_speed(bus));
>   	ut_assertok(dm_i2c_read(dev, 0, buf, 5));
>   	ut_asserteq(-EINVAL, dm_i2c_write(dev, 0, buf, 5));
>
>
Simon Glass Feb. 11, 2015, 7:44 p.m. UTC | #2
On 6 February 2015 at 00:12, Heiko Schocher <hs@denx.de> wrote:
> Hello Simon,
>
> Am 06.02.2015 05:41, schrieb Simon Glass:
>>
>> As with i2c_read() and i2c_write(), add a dm_ prefix to the driver model
>> versions of these functions to avoid conflicts.
>>
>> Signed-off-by: Simon Glass <sjg@chromium.org>
>> ---
>>
>> Changes in v2:
>> - Use a dm_ prefix for remaining conflicting I2C functions
>>
>>   common/cmd_i2c.c         |  4 ++--
>>   drivers/i2c/i2c-uclass.c | 11 +++--------
>>   include/i2c.h            |  8 ++++----
>>   test/dm/i2c.c            |  6 +++---
>>   4 files changed, 12 insertions(+), 17 deletions(-)
>
>
> Thanks!
>
> Acked-by: Heiko Schocher <hs@denx.de>

Applied to u-boot-dm.
diff mbox

Patch

diff --git a/common/cmd_i2c.c b/common/cmd_i2c.c
index 7c3ad00..fe8f77a 100644
--- a/common/cmd_i2c.c
+++ b/common/cmd_i2c.c
@@ -1730,7 +1730,7 @@  static int do_i2c_bus_speed(cmd_tbl_t * cmdtp, int flag, int argc, char * const
 #endif
 	if (argc == 1) {
 #ifdef CONFIG_DM_I2C
-		speed = i2c_get_bus_speed(bus);
+		speed = dm_i2c_get_bus_speed(bus);
 #else
 		speed = i2c_get_bus_speed();
 #endif
@@ -1740,7 +1740,7 @@  static int do_i2c_bus_speed(cmd_tbl_t * cmdtp, int flag, int argc, char * const
 		speed = simple_strtoul(argv[1], NULL, 10);
 		printf("Setting bus speed to %d Hz\n", speed);
 #ifdef CONFIG_DM_I2C
-		ret = i2c_set_bus_speed(bus, speed);
+		ret = dm_i2c_set_bus_speed(bus, speed);
 #else
 		ret = i2c_set_bus_speed(speed);
 #endif
diff --git a/drivers/i2c/i2c-uclass.c b/drivers/i2c/i2c-uclass.c
index eafa457..a6991bf 100644
--- a/drivers/i2c/i2c-uclass.c
+++ b/drivers/i2c/i2c-uclass.c
@@ -325,7 +325,7 @@  int dm_i2c_probe(struct udevice *bus, uint chip_addr, uint chip_flags,
 	return ret;
 }
 
-int i2c_set_bus_speed(struct udevice *bus, unsigned int speed)
+int dm_i2c_set_bus_speed(struct udevice *bus, unsigned int speed)
 {
 	struct dm_i2c_ops *ops = i2c_get_ops(bus);
 	struct dm_i2c_bus *i2c = bus->uclass_priv;
@@ -346,12 +346,7 @@  int i2c_set_bus_speed(struct udevice *bus, unsigned int speed)
 	return 0;
 }
 
-/*
- * i2c_get_bus_speed:
- *
- *  Returns speed of selected I2C bus in Hz
- */
-int i2c_get_bus_speed(struct udevice *bus)
+int dm_i2c_get_bus_speed(struct udevice *bus)
 {
 	struct dm_i2c_ops *ops = i2c_get_ops(bus);
 	struct dm_i2c_bus *i2c = bus->uclass_priv;
@@ -440,7 +435,7 @@  static int i2c_post_probe(struct udevice *dev)
 	i2c->speed_hz = fdtdec_get_int(gd->fdt_blob, dev->of_offset,
 				     "clock-frequency", 100000);
 
-	return i2c_set_bus_speed(dev, i2c->speed_hz);
+	return dm_i2c_set_bus_speed(dev, i2c->speed_hz);
 }
 
 static int i2c_post_bind(struct udevice *dev)
diff --git a/test/dm/i2c.c b/test/dm/i2c.c
index ef88372..541b73b 100644
--- a/test/dm/i2c.c
+++ b/test/dm/i2c.c
@@ -67,10 +67,10 @@  static int dm_test_i2c_speed(struct dm_test_state *dms)
 
 	ut_assertok(uclass_get_device_by_seq(UCLASS_I2C, busnum, &bus));
 	ut_assertok(i2c_get_chip(bus, chip, 1, &dev));
-	ut_assertok(i2c_set_bus_speed(bus, 100000));
+	ut_assertok(dm_i2c_set_bus_speed(bus, 100000));
 	ut_assertok(dm_i2c_read(dev, 0, buf, 5));
-	ut_assertok(i2c_set_bus_speed(bus, 400000));
-	ut_asserteq(400000, i2c_get_bus_speed(bus));
+	ut_assertok(dm_i2c_set_bus_speed(bus, 400000));
+	ut_asserteq(400000, dm_i2c_get_bus_speed(bus));
 	ut_assertok(dm_i2c_read(dev, 0, buf, 5));
 	ut_asserteq(-EINVAL, dm_i2c_write(dev, 0, buf, 5));
diff --git a/include/i2c.h b/include/i2c.h
index 27fe00f..1635e9a 100644
--- a/include/i2c.h
+++ b/include/i2c.h
@@ -125,21 +125,21 @@  int dm_i2c_probe(struct udevice *bus, uint chip_addr, uint chip_flags,
 		 struct udevice **devp);
 
 /**
  * i2c_set_bus_speed() - set the speed of a bus
  *
  * @bus:	Bus to adjust
  * @speed:	Requested speed in Hz
  * @return 0 if OK, -EINVAL for invalid values
  */
-int i2c_set_bus_speed(struct udevice *bus, unsigned int speed);
+int dm_i2c_set_bus_speed(struct udevice *bus, unsigned int speed);
 
 /**
  * i2c_get_bus_speed() - get the speed of a bus
  *
  * @bus:	Bus to check
  * @return speed of selected I2C bus in Hz, -ve on error
  */
-int i2c_get_bus_speed(struct udevice *bus);
+int dm_i2c_get_bus_speed(struct udevice *bus);
 
 /**
  * i2c_set_chip_flags() - set flags for a chip
@@ -125,21 +125,21 @@  int dm_i2c_probe(struct udevice *bus, uint chip_addr, uint chip_flags,
 
 /**
- * i2c_set_bus_speed() - set the speed of a bus
+ * dm_i2c_set_bus_speed() - set the speed of a bus
  *
  * @bus:	Bus to adjust
@@ -125,21 +125,21 @@  int dm_i2c_probe(struct udevice *bus, uint chip_addr, uint chip_flags,
 
 /**
- * i2c_get_bus_speed() - get the speed of a bus
+ * dm_i2c_get_bus_speed() - get the speed of a bus
  *
  * @bus:	Bus to check